=====
Array
=====

The following methods are available under the `Series.arr` attribute.

.. currentmodule:: polars
.. autosummary::
   :toctree: api/
   :template: autosummary/accessor_method.rst

    Series.arr.max
    Series.arr.min
    Series.arr.sum
    Series.arr.unique
